==> pertpy-0.2.0.tar.gz: pertpy-0.2.0/README.md <==
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Build](https://github.com/theislab/pertpy/workflows/Build%20pertpy%20Package/badge.svg)](https://github.com/theislab/pertpy/actions?workflow=Package)
[![Codecov](https://codecov.io/gh/theislab/pertpy/branch/master/graph/badge.svg)](https://codecov.io/gh/theislab/pertpy)
[![License](https://img.shields.io/github/license/theislab/pertpy)](https://opensource.org/licenses/Apache2.0)
[![PyPI](https://img.shields.io/pypi/v/pertpy.svg)](https://pypi.org/project/pertpy/)
[![Python Version](https://img.shields.io/pypi/pyversions/pertpy)](https://pypi.org/project/pertpy)
[![Read the Docs](https://img.shields.io/readthedocs/pertpy/latest.svg?label=Read%20the%20Docs)](https://pertpy.readthedocs.io/)
[![Test](https://github.com/theislab/pertpy/workflows/Run%20pertpy%20Tests/badge.svg)](https://github.com/theislab/pertpy/actions?workflow=Tests)
[![PyPI](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

# pertpy

## Features

-   Differential cell type perturbation analysis with Augurpy

## Installation

You can install _pertpy_ via [pip] from [PyPI]:

```console
$ pip install pertpy
```

## Usage

Please see [Usage] for details.

## Credits

This package was created with [cookietemple] using [Cookiecutter] based on [Hypermodern_Python_Cookiecutter].

[cookiecutter]: https://github.com/audreyr/cookiecutter
[cookietemple]: https://cookietemple.com
[hypermodern_python_cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python
[pip]: https://pip.pypa.io/
[pypi]: https://pypi.org/
[usage]: https://pertpy.readthedocs.io/en/latest/usage.html

==> pertpy-0.3.0.tar.gz: pertpy-0.3.0/README.md <==
[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Build](https://github.com/theislab/pertpy/workflows/Build%20pertpy%20Package/badge.svg)](https://github.com/theislab/pertpy/actions?workflow=Package)
[![Codecov](https://codecov.io/gh/theislab/pertpy/branch/master/graph/badge.svg)](https://codecov.io/gh/theislab/pertpy)
[![License](https://img.shields.io/github/license/theislab/pertpy)](https://opensource.org/licenses/Apache2.0)
[![PyPI](https://img.shields.io/pypi/v/pertpy.svg)](https://pypi.org/project/pertpy/)
[![Python Version](https://img.shields.io/pypi/pyversions/pertpy)](https://pypi.org/project/pertpy)
[![Read the Docs](https://img.shields.io/readthedocs/pertpy/latest.svg?label=Read%20the%20Docs)](https://pertpy.readthedocs.io/)
[![Test](https://github.com/theislab/pertpy/workflows/Run%20pertpy%20Tests/badge.svg)](https://github.com/theislab/pertpy/actions?workflow=Tests)
[![PyPI](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)

# pertpy

## Features

-   Differential cell type perturbation analysis with Augurpy
-   Analysis of CRISPR-KO screens with Mixscape
-   Compositional analysis with Milo and tascCODA

## Installation

You can install _pertpy_ via [pip] from [PyPI]:

```console
$ pip install pertpy
```

## Usage

Please see [Usage] for details.

## Credits

This package was created with [cookietemple] using [Cookiecutter] based on [Hypermodern_Python_Cookiecutter].

[cookiecutter]: https://github.com/audreyr/cookiecutter
[cookietemple]: https://cookietemple.com
[hypermodern_python_cookiecutter]: https://github.com/cjolowicz/cookiecutter-hypermodern-python
[pip]: https://pip.pypa.io/
[pypi]: https://pypi.org/
[usage]: https://pertpy.readthedocs.io/en/latest/usage/usage.html
